# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["CompanyLegalForm"]

CompanyLegalForm: TypeAlias = Literal[
    "ag",
    "eg",
    "ek",
    "ev",
    "ewiv",
    "foreign",
    "gbr",
    "ggmbh",
    "gmbh",
    "kg",
    "kgaa",
    "unknown",
    "llp",
    "municipal",
    "ohg",
    "se",
    "ug",
]
